var searchData=
[
  ['d_0',['d',['../structDav1dSegmentationDataSet.html#a9a5f7c927df14d61f15d06cb0d359f09',1,'Dav1dSegmentationDataSet']]],
  ['damping_1',['damping',['../structDav1dFrameHeader.html#a367442febb62bbcc539c17f473bda63b',1,'Dav1dFrameHeader']]],
  ['data_2',['data',['../structDav1dPicture.html#ae6a2b8538d7a43aaab3f46d2198e67fa',1,'Dav1dPicture::data'],['../structDav1dFrameHeader.html#a0793ad1ee6079e66307a11c3b3bb6432',1,'Dav1dFrameHeader::data'],['../structDav1dData.html#a08e47b7276c43111369e43439f8cfe9f',1,'Dav1dData::data'],['../structDav1dUserData.html#abea83576f25527ba0b464d28e86f2757',1,'Dav1dUserData::data']]],
  ['data_2eh_3',['data.h',['../data_8h.html',1,'']]],
  ['dav1d_2eh_4',['dav1d.h',['../dav1d_8h.html',1,'']]],
  ['dav1d_5fadaptive_5',['DAV1D_ADAPTIVE',['../headers_8h.html#ad2bd41511ca43ef7d9ebf5cb2eaca6c5a66e6af92cf2d442f04a1dd7cab7e2a02',1,'headers.h']]],
  ['dav1d_5fapi_6',['DAV1D_API',['../common_8h.html#a8e46f35f13caf963bb1320ec074639e2',1,'common.h']]],
  ['dav1d_5fapply_5fgrain_7',['dav1d_apply_grain',['../dav1d_8h.html#ad19b315abdff30e72ac3ab276a5ece46',1,'dav1d.h']]],
  ['dav1d_5fchr_5fcolocated_8',['DAV1D_CHR_COLOCATED',['../headers_8h.html#a400522daeb5177ba86ee9da1960bd828a784d356a12baa808a63e6b55fceb667e',1,'headers.h']]],
  ['dav1d_5fchr_5funknown_9',['DAV1D_CHR_UNKNOWN',['../headers_8h.html#a400522daeb5177ba86ee9da1960bd828ac225deb4dc38fcf158aa732ffa3a8bee',1,'headers.h']]],
  ['dav1d_5fchr_5fvertical_10',['DAV1D_CHR_VERTICAL',['../headers_8h.html#a400522daeb5177ba86ee9da1960bd828af1caa03af70334b656dd712e2e69285e',1,'headers.h']]],
  ['dav1d_5fclose_11',['dav1d_close',['../dav1d_8h.html#a57c5dfd3c50e65b48ab9ed65e0f4fd6b',1,'dav1d.h']]],
  ['dav1d_5fcolor_5fpri_5fbt2020_12',['DAV1D_COLOR_PRI_BT2020',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baaebf67a1b8110a34c2694d119fbfb373c',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5fbt470bg_13',['DAV1D_COLOR_PRI_BT470BG',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baae1f32685bb31ebe61895dd124b474d04',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5fbt470m_14',['DAV1D_COLOR_PRI_BT470M',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baa868c20b179e31c6872e8304c3e9a0024',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5fbt601_15',['DAV1D_COLOR_PRI_BT601',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baabe0f5f6859ef4b8052ee4347ea86ac97',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5fbt709_16',['DAV1D_COLOR_PRI_BT709',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baade8603bc7509ab149289386a586f10f0',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5febu3213_17',['DAV1D_COLOR_PRI_EBU3213',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baae7863a18e9d95d1f476bc55d394efe2e',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5ffilm_18',['DAV1D_COLOR_PRI_FILM',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baade6a5a5f9e1f5fc827c03643ac134eb4',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5freserved_19',['DAV1D_COLOR_PRI_RESERVED',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baa41b911097301f0f6b79fd864dd8709ca',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5fsmpte240_20',['DAV1D_COLOR_PRI_SMPTE240',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baa965e87add56d22ad1c0b1fcc7ca82826',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5fsmpte431_21',['DAV1D_COLOR_PRI_SMPTE431',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baad8dd7aad7f3efe115093c54fb48fff64',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5fsmpte432_22',['DAV1D_COLOR_PRI_SMPTE432',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baa47539a89b4bdca214958b31ba0e00a91',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5funknown_23',['DAV1D_COLOR_PRI_UNKNOWN',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baa86fc8f87e4d3af9c62b73f19547b33ab',1,'headers.h']]],
  ['dav1d_5fcolor_5fpri_5fxyz_24',['DAV1D_COLOR_PRI_XYZ',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522baafec0ea8fbded398ffd294dfd67becec1',1,'headers.h']]],
  ['dav1d_5fdata_5fcreate_25',['dav1d_data_create',['../data_8h.html#afd8aa2f4f1382282cb4c267d13ecb0ed',1,'data.h']]],
  ['dav1d_5fdata_5fprops_5funref_26',['dav1d_data_props_unref',['../common_8h.html#ac02c9e1a5fdac32be18aa968b3f2932f',1,'common.h']]],
  ['dav1d_5fdata_5funref_27',['dav1d_data_unref',['../data_8h.html#a74bd791474aa3b9fb4a5b5bc55e7042a',1,'data.h']]],
  ['dav1d_5fdata_5fwrap_28',['dav1d_data_wrap',['../data_8h.html#a1a5285aab3d2d355a35c33079de69dbd',1,'data.h']]],
  ['dav1d_5fdata_5fwrap_5fuser_5fdata_29',['dav1d_data_wrap_user_data',['../data_8h.html#a27a5e69c0b9c7def7beeb9119404ca2b',1,'data.h']]],
  ['dav1d_5fdecodeframetype_5fall_30',['DAV1D_DECODEFRAMETYPE_ALL',['../dav1d_8h.html#af3889050e5a8c526be7343cb5cbfb3d5ab763b3deba13c8784fb1f0f4b5d0d4bd',1,'dav1d.h']]],
  ['dav1d_5fdecodeframetype_5fintra_31',['DAV1D_DECODEFRAMETYPE_INTRA',['../dav1d_8h.html#af3889050e5a8c526be7343cb5cbfb3d5ab8a73223195ca2f940192d225102c698',1,'dav1d.h']]],
  ['dav1d_5fdecodeframetype_5fkey_32',['DAV1D_DECODEFRAMETYPE_KEY',['../dav1d_8h.html#af3889050e5a8c526be7343cb5cbfb3d5a61e79ab94af2ee6094f81e1f86d04b8c',1,'dav1d.h']]],
  ['dav1d_5fdecodeframetype_5freference_33',['DAV1D_DECODEFRAMETYPE_REFERENCE',['../dav1d_8h.html#af3889050e5a8c526be7343cb5cbfb3d5a725d6c0a155396e746bc8c9901a8c689',1,'dav1d.h']]],
  ['dav1d_5fdefault_5fsettings_34',['dav1d_default_settings',['../dav1d_8h.html#aae458711df16114c733da2e3c222488c',1,'dav1d.h']]],
  ['dav1d_5ferr_35',['DAV1D_ERR',['../common_8h.html#ab8bfe3b91c464d5f8f11413919eb16cd',1,'common.h']]],
  ['dav1d_5fevent_5fflag_5fnew_5fop_5fparams_5finfo_36',['DAV1D_EVENT_FLAG_NEW_OP_PARAMS_INFO',['../dav1d_8h.html#a7df42645bae950bcf1ea0a10cf11126da99f97bc1b097832d142c45ca729e4bef',1,'dav1d.h']]],
  ['dav1d_5fevent_5fflag_5fnew_5fsequence_37',['DAV1D_EVENT_FLAG_NEW_SEQUENCE',['../dav1d_8h.html#a7df42645bae950bcf1ea0a10cf11126da251c29f5625946a4061b4d4382877a04',1,'dav1d.h']]],
  ['dav1d_5ffilter_5f8tap_5fregular_38',['DAV1D_FILTER_8TAP_REGULAR',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3deaa227c7396b677a293b6f8884b600cba6a',1,'headers.h']]],
  ['dav1d_5ffilter_5f8tap_5fsharp_39',['DAV1D_FILTER_8TAP_SHARP',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3deaa3848a696af59d71c2348c8ceb37a0c6b',1,'headers.h']]],
  ['dav1d_5ffilter_5f8tap_5fsmooth_40',['DAV1D_FILTER_8TAP_SMOOTH',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3deaabe008fe8c6f714588da00178c5e535d5',1,'headers.h']]],
  ['dav1d_5ffilter_5fbilinear_41',['DAV1D_FILTER_BILINEAR',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3deaad2c374ae7c3b93af8b024235029d466a',1,'headers.h']]],
  ['dav1d_5ffilter_5fswitchable_42',['DAV1D_FILTER_SWITCHABLE',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3deaaf863c2a97769b774306db4a02bab3ded',1,'headers.h']]],
  ['dav1d_5fflush_43',['dav1d_flush',['../dav1d_8h.html#ab4e8543c6f83d59efbad33f14eae1f22',1,'dav1d.h']]],
  ['dav1d_5fframe_5ftype_5finter_44',['DAV1D_FRAME_TYPE_INTER',['../headers_8h.html#a954a0cd0943914e145e0f704f5041893a6515a0ce27260edaf32fa64532196c33',1,'headers.h']]],
  ['dav1d_5fframe_5ftype_5fintra_45',['DAV1D_FRAME_TYPE_INTRA',['../headers_8h.html#a954a0cd0943914e145e0f704f5041893a14f5eddac01a833c5c6b750d7e342bd7',1,'headers.h']]],
  ['dav1d_5fframe_5ftype_5fkey_46',['DAV1D_FRAME_TYPE_KEY',['../headers_8h.html#a954a0cd0943914e145e0f704f5041893a9bf03bc1e8e211f537a3f82400b29ae2',1,'headers.h']]],
  ['dav1d_5fframe_5ftype_5fswitch_47',['DAV1D_FRAME_TYPE_SWITCH',['../headers_8h.html#a954a0cd0943914e145e0f704f5041893ade37eb5d58cbbc410e1897a9aae465cc',1,'headers.h']]],
  ['dav1d_5fget_5fdecode_5ferror_5fdata_5fprops_48',['dav1d_get_decode_error_data_props',['../dav1d_8h.html#aff844ed31b5e1f8249638154103cca29',1,'dav1d.h']]],
  ['dav1d_5fget_5fevent_5fflags_49',['dav1d_get_event_flags',['../dav1d_8h.html#a989bb8be71d5a2d59e57c03b1fe9e823',1,'dav1d.h']]],
  ['dav1d_5fget_5fframe_5fdelay_50',['dav1d_get_frame_delay',['../dav1d_8h.html#afced59c1dd6ae454f5800bcd243157e8',1,'dav1d.h']]],
  ['dav1d_5fget_5fpicture_51',['dav1d_get_picture',['../dav1d_8h.html#a231e6aa679d5e46fcdac7546f03a6506',1,'dav1d.h']]],
  ['dav1d_5finloopfilter_5fall_52',['DAV1D_INLOOPFILTER_ALL',['../dav1d_8h.html#a42530b0ec0474e5c9ed2e85442ec7b67aa0cb9ea1e228066a7475657df020ed04',1,'dav1d.h']]],
  ['dav1d_5finloopfilter_5fcdef_53',['DAV1D_INLOOPFILTER_CDEF',['../dav1d_8h.html#a42530b0ec0474e5c9ed2e85442ec7b67a4d1f5f583c4686f6cbde5a5fcfabe8d3',1,'dav1d.h']]],
  ['dav1d_5finloopfilter_5fdeblock_54',['DAV1D_INLOOPFILTER_DEBLOCK',['../dav1d_8h.html#a42530b0ec0474e5c9ed2e85442ec7b67ab04e1bb930b2d8d3b44fbbefbc055170',1,'dav1d.h']]],
  ['dav1d_5finloopfilter_5fnone_55',['DAV1D_INLOOPFILTER_NONE',['../dav1d_8h.html#a42530b0ec0474e5c9ed2e85442ec7b67a78aeb454f4fc4c1b7da2c42a7c040528',1,'dav1d.h']]],
  ['dav1d_5finloopfilter_5frestoration_56',['DAV1D_INLOOPFILTER_RESTORATION',['../dav1d_8h.html#a42530b0ec0474e5c9ed2e85442ec7b67ab8387d3ba8989101d6ef389eeae87a36',1,'dav1d.h']]],
  ['dav1d_5fmax_5fcdef_5fstrengths_57',['DAV1D_MAX_CDEF_STRENGTHS',['../headers_8h.html#a6d3a740e48c5f01c9f4c3fc508077d0a',1,'headers.h']]],
  ['dav1d_5fmax_5fframe_5fdelay_58',['DAV1D_MAX_FRAME_DELAY',['../dav1d_8h.html#ab58c9fcc5f207d2452618a36e79ddd27',1,'dav1d.h']]],
  ['dav1d_5fmax_5foperating_5fpoints_59',['DAV1D_MAX_OPERATING_POINTS',['../headers_8h.html#a3a6828cd51839b6fe1f3edc91e29916f',1,'headers.h']]],
  ['dav1d_5fmax_5fsegments_60',['DAV1D_MAX_SEGMENTS',['../headers_8h.html#a9168299c410dc89d022549b06b375d96',1,'headers.h']]],
  ['dav1d_5fmax_5fthreads_61',['DAV1D_MAX_THREADS',['../dav1d_8h.html#a1271d397b937de2bbf0149193030d2a8',1,'dav1d.h']]],
  ['dav1d_5fmax_5ftile_5fcols_62',['DAV1D_MAX_TILE_COLS',['../headers_8h.html#a8935432e8d0cf0da86cfaf5ff3ed8c89',1,'headers.h']]],
  ['dav1d_5fmax_5ftile_5frows_63',['DAV1D_MAX_TILE_ROWS',['../headers_8h.html#a782b8dfa823460b9140715513edce715',1,'headers.h']]],
  ['dav1d_5fmc_5fbt2020_5fcl_64',['DAV1D_MC_BT2020_CL',['../headers_8h.html#ab615aa670362bc69fc4177e07585399ba352b649ab9b9c0cc8a59587e6f8d816b',1,'headers.h']]],
  ['dav1d_5fmc_5fbt2020_5fncl_65',['DAV1D_MC_BT2020_NCL',['../headers_8h.html#ab615aa670362bc69fc4177e07585399ba844590f7caf605d1f7d893a290016278',1,'headers.h']]],
  ['dav1d_5fmc_5fbt470bg_66',['DAV1D_MC_BT470BG',['../headers_8h.html#ab615aa670362bc69fc4177e07585399bacc6f92859ca804613700f08e16701985',1,'headers.h']]],
  ['dav1d_5fmc_5fbt601_67',['DAV1D_MC_BT601',['../headers_8h.html#ab615aa670362bc69fc4177e07585399ba0214894203dd0338b032d2aa11e98d32',1,'headers.h']]],
  ['dav1d_5fmc_5fbt709_68',['DAV1D_MC_BT709',['../headers_8h.html#ab615aa670362bc69fc4177e07585399bac813148584a34026e7ccdad2a7e0ec10',1,'headers.h']]],
  ['dav1d_5fmc_5fchromat_5fcl_69',['DAV1D_MC_CHROMAT_CL',['../headers_8h.html#ab615aa670362bc69fc4177e07585399bafc7bc26b7c54c1f9d5040e646208361d',1,'headers.h']]],
  ['dav1d_5fmc_5fchromat_5fncl_70',['DAV1D_MC_CHROMAT_NCL',['../headers_8h.html#ab615aa670362bc69fc4177e07585399baf3f3cb6f580bcc72f8baf891d01b7e84',1,'headers.h']]],
  ['dav1d_5fmc_5ffcc_71',['DAV1D_MC_FCC',['../headers_8h.html#ab615aa670362bc69fc4177e07585399baaad78eb96164ca9833e5ccd349571372',1,'headers.h']]],
  ['dav1d_5fmc_5fictcp_72',['DAV1D_MC_ICTCP',['../headers_8h.html#ab615aa670362bc69fc4177e07585399ba27bcf84dbd98a00541df47a2cfad5e8c',1,'headers.h']]],
  ['dav1d_5fmc_5fidentity_73',['DAV1D_MC_IDENTITY',['../headers_8h.html#ab615aa670362bc69fc4177e07585399ba2f74d944a5f414881469aebef7bc310e',1,'headers.h']]],
  ['dav1d_5fmc_5freserved_74',['DAV1D_MC_RESERVED',['../headers_8h.html#ab615aa670362bc69fc4177e07585399bad045d25ab4b6b760540f5b83f45237f7',1,'headers.h']]],
  ['dav1d_5fmc_5fsmpte2085_75',['DAV1D_MC_SMPTE2085',['../headers_8h.html#ab615aa670362bc69fc4177e07585399ba6d92525da654000898e0e8e23176a86b',1,'headers.h']]],
  ['dav1d_5fmc_5fsmpte240_76',['DAV1D_MC_SMPTE240',['../headers_8h.html#ab615aa670362bc69fc4177e07585399ba0995f79b03d84c2a48571b8687ae26fe',1,'headers.h']]],
  ['dav1d_5fmc_5fsmpte_5fycgco_77',['DAV1D_MC_SMPTE_YCGCO',['../headers_8h.html#ab615aa670362bc69fc4177e07585399ba13bfcdcd42b416bde6d40a17bdb1e688',1,'headers.h']]],
  ['dav1d_5fmc_5funknown_78',['DAV1D_MC_UNKNOWN',['../headers_8h.html#ab615aa670362bc69fc4177e07585399bac5e86f6836a7b0b548c7148a206b8f0b',1,'headers.h']]],
  ['dav1d_5fn_5ffilters_79',['DAV1D_N_FILTERS',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3deaa5da26458800d8aa301ba86bcc19a25a8',1,'headers.h']]],
  ['dav1d_5fn_5fswitchable_5ffilters_80',['DAV1D_N_SWITCHABLE_FILTERS',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3deaa2e8c80f5884e20973deb8883e6687f2f',1,'headers.h']]],
  ['dav1d_5fn_5ftx_5fmodes_81',['DAV1D_N_TX_MODES',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8a51ea05f7ef69d4acc6f99f0246198fdd',1,'headers.h']]],
  ['dav1d_5fnum_5fref_5fframes_82',['DAV1D_NUM_REF_FRAMES',['../headers_8h.html#ac3445b278a62f1964f391be8d2476962',1,'headers.h']]],
  ['dav1d_5fobu_5fframe_83',['DAV1D_OBU_FRAME',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2a1ea16e9b08c20f72280a4a6fdcd517f1',1,'headers.h']]],
  ['dav1d_5fobu_5fframe_5fhdr_84',['DAV1D_OBU_FRAME_HDR',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2ae2bc27459b3c7798a5a05a5e47b59399',1,'headers.h']]],
  ['dav1d_5fobu_5fmetadata_85',['DAV1D_OBU_METADATA',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2a65e40b75a0667d283fe01fd3d4e437de',1,'headers.h']]],
  ['dav1d_5fobu_5fpadding_86',['DAV1D_OBU_PADDING',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2a1e92c2771e271cab7cef4a11222157ff',1,'headers.h']]],
  ['dav1d_5fobu_5fredundant_5fframe_5fhdr_87',['DAV1D_OBU_REDUNDANT_FRAME_HDR',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2a74cdc163ee5013af81dd99b7780191f2',1,'headers.h']]],
  ['dav1d_5fobu_5fseq_5fhdr_88',['DAV1D_OBU_SEQ_HDR',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2af144e87386ea45facaec114ed1f8d6ad',1,'headers.h']]],
  ['dav1d_5fobu_5ftd_89',['DAV1D_OBU_TD',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2ac9462b2bbe1a35eddb9cc1772a5786f4',1,'headers.h']]],
  ['dav1d_5fobu_5ftile_5fgrp_90',['DAV1D_OBU_TILE_GRP',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2aab0491f1c7baca06c8decd0ddd6fedaf',1,'headers.h']]],
  ['dav1d_5foff_91',['DAV1D_OFF',['../headers_8h.html#ad2bd41511ca43ef7d9ebf5cb2eaca6c5a7e2cd05ab804ec0242a81fe35b278b0e',1,'headers.h']]],
  ['dav1d_5fon_92',['DAV1D_ON',['../headers_8h.html#ad2bd41511ca43ef7d9ebf5cb2eaca6c5add64ee6b4fa72de32d02b27a1934a8a4',1,'headers.h']]],
  ['dav1d_5fopen_93',['dav1d_open',['../dav1d_8h.html#a6cf42b3e954f16afc527e0dadbb14099',1,'dav1d.h']]],
  ['dav1d_5fparse_5fsequence_5fheader_94',['dav1d_parse_sequence_header',['../dav1d_8h.html#a97efb0ec561878ae0921fadf27b7f5cb',1,'dav1d.h']]],
  ['dav1d_5fpicture_5falignment_95',['DAV1D_PICTURE_ALIGNMENT',['../picture_8h.html#aa60e80b4782a1e9c7ef89dcd957700f3',1,'picture.h']]],
  ['dav1d_5fpicture_5funref_96',['dav1d_picture_unref',['../picture_8h.html#a51be95661e4212a556a531bb9b3c70cf',1,'picture.h']]],
  ['dav1d_5fpixel_5flayout_5fi400_97',['DAV1D_PIXEL_LAYOUT_I400',['../headers_8h.html#a337615b8db1a0271c5c30e23cd7c8a7dac422079631fc66b3fdbd3efebeee9044',1,'headers.h']]],
  ['dav1d_5fpixel_5flayout_5fi420_98',['DAV1D_PIXEL_LAYOUT_I420',['../headers_8h.html#a337615b8db1a0271c5c30e23cd7c8a7daf1a3037b324189760dcba03d41b2cfa3',1,'headers.h']]],
  ['dav1d_5fpixel_5flayout_5fi422_99',['DAV1D_PIXEL_LAYOUT_I422',['../headers_8h.html#a337615b8db1a0271c5c30e23cd7c8a7dacc2c4e96e671bc58653cccabb4887460',1,'headers.h']]],
  ['dav1d_5fpixel_5flayout_5fi444_100',['DAV1D_PIXEL_LAYOUT_I444',['../headers_8h.html#a337615b8db1a0271c5c30e23cd7c8a7da1d66a191c7206703b8d6715196e20259',1,'headers.h']]],
  ['dav1d_5fprimary_5fref_5fnone_101',['DAV1D_PRIMARY_REF_NONE',['../headers_8h.html#ab62e142ad93daa0fc8f4df3df42e3632',1,'headers.h']]],
  ['dav1d_5frefs_5fper_5fframe_102',['DAV1D_REFS_PER_FRAME',['../headers_8h.html#a470e18d2e7a443f8f3d3edf6d2f757ce',1,'headers.h']]],
  ['dav1d_5frestoration_5fnone_103',['DAV1D_RESTORATION_NONE',['../headers_8h.html#a01ae1f8699c751072c60e4c3e0efd301a675591c0b48f3a99dcaaa4f22759e325',1,'headers.h']]],
  ['dav1d_5frestoration_5fsgrproj_104',['DAV1D_RESTORATION_SGRPROJ',['../headers_8h.html#a01ae1f8699c751072c60e4c3e0efd301a40b5d8495309e389ca5ac231b4612b85',1,'headers.h']]],
  ['dav1d_5frestoration_5fswitchable_105',['DAV1D_RESTORATION_SWITCHABLE',['../headers_8h.html#a01ae1f8699c751072c60e4c3e0efd301abdb68324056113297bb556ca300ca6a8',1,'headers.h']]],
  ['dav1d_5frestoration_5fwiener_106',['DAV1D_RESTORATION_WIENER',['../headers_8h.html#a01ae1f8699c751072c60e4c3e0efd301a842bb766aa9cdcc3fcd2ce6ad4c2041a',1,'headers.h']]],
  ['dav1d_5fsend_5fdata_107',['dav1d_send_data',['../dav1d_8h.html#ab2e81b8a272d07ba3f80fb66b980b874',1,'dav1d.h']]],
  ['dav1d_5ftotal_5frefs_5fper_5fframe_108',['DAV1D_TOTAL_REFS_PER_FRAME',['../headers_8h.html#a2cbcb5325c5f547a19a9ed3c743c3184',1,'headers.h']]],
  ['dav1d_5ftrc_5fbt1361_109',['DAV1D_TRC_BT1361',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ead58d5708d80184990f8028c0c865fe1c',1,'headers.h']]],
  ['dav1d_5ftrc_5fbt2020_5f10bit_110',['DAV1D_TRC_BT2020_10BIT',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea86dea1407b22f0a8664c825268fc90f3',1,'headers.h']]],
  ['dav1d_5ftrc_5fbt2020_5f12bit_111',['DAV1D_TRC_BT2020_12BIT',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea9d69ec699cd37873b3534dd31402a497',1,'headers.h']]],
  ['dav1d_5ftrc_5fbt470bg_112',['DAV1D_TRC_BT470BG',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4eaabf741eb240c0ff9a96f3dfedb61b1a3',1,'headers.h']]],
  ['dav1d_5ftrc_5fbt470m_113',['DAV1D_TRC_BT470M',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4eab6c9f4f65ab7d9d2d1132158610e555b',1,'headers.h']]],
  ['dav1d_5ftrc_5fbt601_114',['DAV1D_TRC_BT601',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea09383e423f32db45dbd8bdf619ba5e82',1,'headers.h']]],
  ['dav1d_5ftrc_5fbt709_115',['DAV1D_TRC_BT709',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea4704c633f014a05427b969b4f089d14e',1,'headers.h']]],
  ['dav1d_5ftrc_5fhlg_116',['DAV1D_TRC_HLG',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4eacb2b8e80792ac8abe1f9e18e366a7f19',1,'headers.h']]],
  ['dav1d_5ftrc_5fiec61966_117',['DAV1D_TRC_IEC61966',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4eabab1fcdf91e6300d3759207caa300df5',1,'headers.h']]],
  ['dav1d_5ftrc_5flinear_118',['DAV1D_TRC_LINEAR',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea37acdb6b5d113cec853ab10215cebd61',1,'headers.h']]],
  ['dav1d_5ftrc_5flog100_119',['DAV1D_TRC_LOG100',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ead1fc165ee82b1f2f0ed8dd6b91158915',1,'headers.h']]],
  ['dav1d_5ftrc_5flog100_5fsqrt10_120',['DAV1D_TRC_LOG100_SQRT10',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea7e07287ee16173a88bdc47713ef44d5c',1,'headers.h']]],
  ['dav1d_5ftrc_5freserved_121',['DAV1D_TRC_RESERVED',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4eaecdb427ff7b17ac3875b178946b08c8e',1,'headers.h']]],
  ['dav1d_5ftrc_5fsmpte2084_122',['DAV1D_TRC_SMPTE2084',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea07f6761a8a26a1737334ad233e442d56',1,'headers.h']]],
  ['dav1d_5ftrc_5fsmpte240_123',['DAV1D_TRC_SMPTE240',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea3aff834043e51db3354469267b655469',1,'headers.h']]],
  ['dav1d_5ftrc_5fsmpte428_124',['DAV1D_TRC_SMPTE428',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4ea26b977971d0a721aa30b92cb1311157a',1,'headers.h']]],
  ['dav1d_5ftrc_5fsrgb_125',['DAV1D_TRC_SRGB',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4eae9af66f5f069aa9173caba9764a1ca5e',1,'headers.h']]],
  ['dav1d_5ftrc_5funknown_126',['DAV1D_TRC_UNKNOWN',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4eabb94b3eec01989f8a94e3be6357ab113',1,'headers.h']]],
  ['dav1d_5ftx_5f4x4_5fonly_127',['DAV1D_TX_4X4_ONLY',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8ac4b08da4153d16c58633216f4dff062d',1,'headers.h']]],
  ['dav1d_5ftx_5flargest_128',['DAV1D_TX_LARGEST',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8a76279b87af8c7fb1b8c586acf90dae4c',1,'headers.h']]],
  ['dav1d_5ftx_5fswitchable_129',['DAV1D_TX_SWITCHABLE',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8adc6182d0aae1bd4e1effff09d2fca74c',1,'headers.h']]],
  ['dav1d_5fversion_130',['dav1d_version',['../dav1d_8h.html#a9ec06f24b3798b1123dc7d3e468bbac4',1,'dav1d.h']]],
  ['dav1d_5fwm_5ftype_5faffine_131',['DAV1D_WM_TYPE_AFFINE',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97a6d12578cc1105b97989eadacf5cd67dc',1,'headers.h']]],
  ['dav1d_5fwm_5ftype_5fidentity_132',['DAV1D_WM_TYPE_IDENTITY',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97a24db5aa662a1365b33d4f2ebc1bec9f9',1,'headers.h']]],
  ['dav1d_5fwm_5ftype_5frot_5fzoom_133',['DAV1D_WM_TYPE_ROT_ZOOM',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97afb1a4a46bbd3239fda49e7f0adc6cbe5',1,'headers.h']]],
  ['dav1d_5fwm_5ftype_5ftranslation_134',['DAV1D_WM_TYPE_TRANSLATION',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97ae6b2d94797bf270106ccb4390ecc6c1a',1,'headers.h']]],
  ['dav1dadaptiveboolean_135',['Dav1dAdaptiveBoolean',['../headers_8h.html#ad2bd41511ca43ef7d9ebf5cb2eaca6c5',1,'headers.h']]],
  ['dav1dchromasampleposition_136',['Dav1dChromaSamplePosition',['../headers_8h.html#a400522daeb5177ba86ee9da1960bd828',1,'headers.h']]],
  ['dav1dcolorprimaries_137',['Dav1dColorPrimaries',['../headers_8h.html#a4e56e3b70ab263bd7fe11599095522ba',1,'headers.h']]],
  ['dav1dcontentlightlevel_138',['Dav1dContentLightLevel',['../structDav1dContentLightLevel.html',1,'']]],
  ['dav1dcontext_139',['Dav1dContext',['../dav1d_8h.html#a7f3e646528835d5abcc352a1c0e20c31',1,'dav1d.h']]],
  ['dav1ddata_140',['Dav1dData',['../structDav1dData.html',1,'']]],
  ['dav1ddataprops_141',['Dav1dDataProps',['../structDav1dDataProps.html',1,'']]],
  ['dav1ddecodeframetype_142',['Dav1dDecodeFrameType',['../dav1d_8h.html#af3889050e5a8c526be7343cb5cbfb3d5',1,'dav1d.h']]],
  ['dav1deventflags_143',['Dav1dEventFlags',['../dav1d_8h.html#a7df42645bae950bcf1ea0a10cf11126d',1,'dav1d.h']]],
  ['dav1dfilmgraindata_144',['Dav1dFilmGrainData',['../structDav1dFilmGrainData.html',1,'']]],
  ['dav1dfiltermode_145',['Dav1dFilterMode',['../headers_8h.html#a27f2225f3bd5d665d7969f3d59bb3dea',1,'headers.h']]],
  ['dav1dframeheader_146',['Dav1dFrameHeader',['../structDav1dFrameHeader.html',1,'']]],
  ['dav1dframeheaderoperatingpoint_147',['Dav1dFrameHeaderOperatingPoint',['../structDav1dFrameHeader_1_1Dav1dFrameHeaderOperatingPoint.html',1,'Dav1dFrameHeader']]],
  ['dav1dframetype_148',['Dav1dFrameType',['../headers_8h.html#a954a0cd0943914e145e0f704f5041893',1,'headers.h']]],
  ['dav1dinloopfiltertype_149',['Dav1dInloopFilterType',['../dav1d_8h.html#a42530b0ec0474e5c9ed2e85442ec7b67',1,'dav1d.h']]],
  ['dav1ditutt35_150',['Dav1dITUTT35',['../structDav1dITUTT35.html',1,'']]],
  ['dav1dlogger_151',['Dav1dLogger',['../structDav1dLogger.html',1,'']]],
  ['dav1dloopfiltermoderefdeltas_152',['Dav1dLoopfilterModeRefDeltas',['../structDav1dLoopfilterModeRefDeltas.html',1,'']]],
  ['dav1dmasteringdisplay_153',['Dav1dMasteringDisplay',['../structDav1dMasteringDisplay.html',1,'']]],
  ['dav1dmatrixcoefficients_154',['Dav1dMatrixCoefficients',['../headers_8h.html#ab615aa670362bc69fc4177e07585399b',1,'headers.h']]],
  ['dav1dobutype_155',['Dav1dObuType',['../headers_8h.html#a0ec75c7af65e97131c0985b8dd30e3b2',1,'headers.h']]],
  ['dav1dpicallocator_156',['Dav1dPicAllocator',['../structDav1dPicAllocator.html',1,'']]],
  ['dav1dpicture_157',['Dav1dPicture',['../structDav1dPicture.html',1,'']]],
  ['dav1dpictureparameters_158',['Dav1dPictureParameters',['../structDav1dPictureParameters.html',1,'']]],
  ['dav1dpixellayout_159',['Dav1dPixelLayout',['../headers_8h.html#a337615b8db1a0271c5c30e23cd7c8a7d',1,'headers.h']]],
  ['dav1dref_160',['Dav1dRef',['../dav1d_8h.html#a5f3cad70d6c7586b658d1d25b0355840',1,'dav1d.h']]],
  ['dav1drestorationtype_161',['Dav1dRestorationType',['../headers_8h.html#a01ae1f8699c751072c60e4c3e0efd301',1,'headers.h']]],
  ['dav1dsegmentationdata_162',['Dav1dSegmentationData',['../structDav1dSegmentationData.html',1,'']]],
  ['dav1dsegmentationdataset_163',['Dav1dSegmentationDataSet',['../structDav1dSegmentationDataSet.html',1,'']]],
  ['dav1dsequenceheader_164',['Dav1dSequenceHeader',['../structDav1dSequenceHeader.html',1,'']]],
  ['dav1dsequenceheaderoperatingparameterinfo_165',['Dav1dSequenceHeaderOperatingParameterInfo',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html',1,'Dav1dSequenceHeader']]],
  ['dav1dsequenceheaderoperatingpoint_166',['Dav1dSequenceHeaderOperatingPoint',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html',1,'Dav1dSequenceHeader']]],
  ['dav1dsettings_167',['Dav1dSettings',['../structDav1dSettings.html',1,'']]],
  ['dav1dtransfercharacteristics_168',['Dav1dTransferCharacteristics',['../headers_8h.html#a6e3ff7ce0d25b5dd6b4486ecf98cce4e',1,'headers.h']]],
  ['dav1dtxfmmode_169',['Dav1dTxfmMode',['../headers_8h.html#aef6b43d33f6a8d5203bf6f99d2e0b9b8',1,'headers.h']]],
  ['dav1duserdata_170',['Dav1dUserData',['../structDav1dUserData.html',1,'']]],
  ['dav1dwarpedmotionparams_171',['Dav1dWarpedMotionParams',['../structDav1dWarpedMotionParams.html',1,'']]],
  ['dav1dwarpedmotiontype_172',['Dav1dWarpedMotionType',['../headers_8h.html#a8481d0fd0e60324f72cbab2efe17fe97',1,'headers.h']]],
  ['decode_5fframe_5ftype_173',['decode_frame_type',['../structDav1dSettings.html#a54a22d80474a060f5e92a3f858780f23',1,'Dav1dSettings']]],
  ['decoder_5fbuffer_5fdelay_174',['decoder_buffer_delay',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html#af793e75b7698824189eb9fb506e3ba91',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingParameterInfo']]],
  ['decoder_5fmodel_5finfo_5fpresent_175',['decoder_model_info_present',['../structDav1dSequenceHeader.html#a6bab00a018e0a1ffb7c01eca7cd2e1d6',1,'Dav1dSequenceHeader']]],
  ['decoder_5fmodel_5fparam_5fpresent_176',['decoder_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a4c798f7eb4166a61cbcd3149b5553ddc',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
  ['delta_177',['delta',['../structDav1dWarpedMotionParams.html#a4eb152e946d0c075cec1007857f480ad',1,'Dav1dWarpedMotionParams::delta'],['../structDav1dFrameHeader.html#ac1e90b1fcfbcb834a3c9f051cd3774cf',1,'Dav1dFrameHeader::delta']]],
  ['delta_5fframe_5fid_5fn_5fbits_178',['delta_frame_id_n_bits',['../structDav1dSequenceHeader.html#ac9e01409b43b5ec65ae98c911234ce40',1,'Dav1dSequenceHeader']]],
  ['delta_5flf_5fu_179',['delta_lf_u',['../structDav1dSegmentationData.html#ae61b74492ae6ee1320d1663dd907e0ea',1,'Dav1dSegmentationData']]],
  ['delta_5flf_5fv_180',['delta_lf_v',['../structDav1dSegmentationData.html#ac7f645e6d299541eb72829c007e01fc5',1,'Dav1dSegmentationData']]],
  ['delta_5flf_5fy_5fh_181',['delta_lf_y_h',['../structDav1dSegmentationData.html#a7e41d6e7588adeee5cbf473694fde160',1,'Dav1dSegmentationData']]],
  ['delta_5flf_5fy_5fv_182',['delta_lf_y_v',['../structDav1dSegmentationData.html#ac262acad78c2dfcd5310fda34c93bc55',1,'Dav1dSegmentationData']]],
  ['delta_5fq_183',['delta_q',['../structDav1dSegmentationData.html#ae0445170e6ccd7f4dffdf97d443a00d4',1,'Dav1dSegmentationData']]],
  ['disable_5fcdf_5fupdate_184',['disable_cdf_update',['../structDav1dFrameHeader.html#af5d6782a4043529a70bbd3a3c27c6560',1,'Dav1dFrameHeader']]],
  ['display_5fmodel_5finfo_5fpresent_185',['display_model_info_present',['../structDav1dSequenceHeader.html#a0c6e87f5539cc5cdac0f157c0ba2725f',1,'Dav1dSequenceHeader']]],
  ['display_5fmodel_5fparam_5fpresent_186',['display_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a2d86a6a9b3cadf3304901b1ef38a11f5',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
  ['dual_5ffilter_187',['dual_filter',['../structDav1dSequenceHeader.html#a196eb28472b2a4b8387d47747160deb6',1,'Dav1dSequenceHeader']]],
  ['duration_188',['duration',['../structDav1dDataProps.html#aedb99d78a3677949765aeeedb352e3ac',1,'Dav1dDataProps']]]
];
